aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorselsta <selsta@sent.at>2022-03-01 00:24:38 +0100
committerselsta <selsta@sent.at>2022-03-01 00:38:54 +0100
commitf43e15011d100dc700fa57e08b10beae21acbce8 (patch)
treee6b8a258e798d0c0ffac342635bf8e54c6645f97
parentMerge pull request #8096 (diff)
downloadmonero-f43e15011d100dc700fa57e08b10beae21acbce8.tar.xz
wallet2: update stagenet rollback blocks
-rw-r--r--src/wallet/wallet2.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/wallet/wallet2.cpp b/src/wallet/wallet2.cpp
index cbdda4f72..ecb5b4c57 100644
--- a/src/wallet/wallet2.cpp
+++ b/src/wallet/wallet2.cpp
@@ -12195,10 +12195,10 @@ uint64_t wallet2::get_approximate_blockchain_height() const
const int seconds_per_block = DIFFICULTY_TARGET_V2;
// Calculated blockchain height
uint64_t approx_blockchain_height = fork_block + (time(NULL) - fork_time)/seconds_per_block;
- // testnet got some huge rollbacks, so the estimation is way off
- static const uint64_t approximate_testnet_rolled_back_blocks = 342100;
- if (m_nettype == TESTNET && approx_blockchain_height > approximate_testnet_rolled_back_blocks)
- approx_blockchain_height -= approximate_testnet_rolled_back_blocks;
+ // testnet and stagenet got some huge rollbacks, so the estimation is way off
+ static const uint64_t approximate_rolled_back_blocks = m_nettype == TESTNET ? 342100 : 30000;
+ if ((m_nettype == TESTNET || m_nettype == STAGENET) && approx_blockchain_height > approximate_rolled_back_blocks)
+ approx_blockchain_height -= approximate_rolled_back_blocks;
LOG_PRINT_L2("Calculated blockchain height: " << approx_blockchain_height);
return approx_blockchain_height;
}